from enum import Enum

class GaugingStation(Enum):
    AbiaDeLasTorres = 1
    Aguilafuente = 2
    AlarDelRey = 3
    Alconada = 4
    AlijaDeLaRibera = 5
    Almazan = 6
    Ambasaguas = 7
    ArandaDeDuero = 8
    Arbejal = 9
    Arevalo = 10
    Avila = 11
    BarbadilloDelPez = 12
    Benamariel2 = 13
    Benegiles = 14
    Bernardos = 15
    Besande = 16
    BocaDeHuergano = 17
    Boisan = 18
    Breto = 19
    BrimeDeUrz = 20
    Burgos_Arlanzon = 21
    Burgos_Vena = 22
    CabanesDeEsgueva = 23
    CabezonDePisuerga = 24
    CaldasDeNocedo = 25
    Camarzana_Regato = 26
    CamarzanaDeTera = 27
    Camposolillo = 28
    CardanoDeArriba = 29
    Cascantes = 30
    CastreloDoVal = 31
    CastroDeLaLomba = 32
    Castropepe = 33
    CebronesDelRio = 34
    CeladaDelCamino = 35
    CeladillaDelRio = 36
    Cistierna = 37
    CiudadRodrigo = 38
    Coca_Eresma = 39
    Coca_Voltoya = 40
    Cordovilla = 41
    Covarrubias = 42
    Cremenes = 43
    ElBarcoDeAvila = 44
    EmisarioDeLaNava = 45
    EncinasDeAbajo = 46
    Garray_Soria = 47
    Genestacio = 48
    Getino = 49
    Gormaz = 50
    Guardo = 51
    GuijasAlbas = 52
    HerreraDeDuero = 53
    HerreraDePisuerga = 54
    HoyosDelEspino = 55
    LaFuentona = 56
    LaMagdalena = 57
    Languilla = 58
    LasOmanas = 59
    LasSalas = 60
    Ledesma = 61
    Leon = 62
    Lerma = 63
    Liegos = 64
    LinaresDelArroyo = 65
    LosAngelesDeSanRafael = 66
    Manganeses = 67
    MedianaDeVoltoya = 68
    MedinaDeRioseco = 69
    MedinaDelCampo = 70
    Megeces = 71
    MolinosDeDuero = 72
    Monderio = 73
    MoralesDelRey = 74
    MorlaDeLaValderia = 75
    MozarDeValverde = 76
    Navapalos = 77
    Osma = 78
    OteroDeGuardo = 79
    PajaresDePedraza = 80
    PalaciosDeLaSierra = 81
    Palencia = 82
    Pardave = 83
    PedrosaDelPrincipe = 84
    PeralDeArlanza = 85
    PinedaDeLaSierra = 86
    PinillaDeLosMoros = 87
    PueblaDeSanabria = 88
    PuenteCongosto = 89
    PuenteResbala = 90
    QuintanaDelCastillo = 91
    QuintanaDelPuente = 92
    Quintanaduenas = 93
    QuintanillaDeOnesimo = 94
    Rabal = 95
    Remolina = 96
    Resoba = 97
    Riaza = 98
    Robleda = 99
    Ruesga = 100
    SaelicesElChico = 101
    Sahagun = 102
    Salamanca = 103
    SalasDeLosInfantes = 104
    SalidaDelEmbalseDeAguilarDeCampoo = 105
    SalidaDelEmbalseDeArlanzon = 106
    SalidaDelEmbalseDeBarriosDeLuna = 107
    SalidaDelEmbalseDeCamporredondo = 108
    SalidaDelEmbalseDeCasares = 109
    SalidaDelEmbalseDeCastroDeLasCogotas = 110
    SalidaDelEmbalseDeCastrovido = 111
    SalidaDelEmbalseDeCervera = 112
    SalidaDelEmbalseDeCompuerto = 113
    SalidaDelEmbalseDeElPontonAlto = 114
    SalidaDelEmbalseDeIruena = 115
    SalidaDelEmbalseDeLaCuerdaDelPozo = 116
    SalidaDelEmbalseDeLasVencias = 117
    SalidaDelEmbalseDeLinares = 118
    SalidaDelEmbalseDeSantaTeresa = 119
    SalidaDelEmbalseDeUzquiza = 120
    SalidaDelEmbalseDeVillameca = 121
    SalidaDelEmbalseDelAgueda = 122
    SalidaDelEmbalseDelPorma = 123
    SalinasDePisuerga = 124
    SanFelixDeLaVega = 125
    SanMiguelDelPino = 126
    SanSalvadorDeCantamuda = 127
    SantaCristinaDeLaPolvorosa = 128
    SantaEulaliaDeRionegro = 129
    SantaMarinaDelRey = 130
    SantervasDeCampos = 131
    SantiagoDeLaValduerna = 132
    Saucelle_Duero = 133
    Saucelle_Huebra = 134
    Secos = 135
    Segovia = 136
    SenaDeLuna = 137
    Sepulveda = 138
    TardajosDeDuero = 139
    Tardesillas = 140
    TolibiaDeAbajo = 141
    Toro_Duero = 142
    Toro_Guarena = 143
    TorreDeEsgueva = 144
    Triollo = 145
    Ucero = 146
    Vadocondes = 147
    Valderas = 148
    Valdestillas = 149
    Valladolid_Esgueva = 150
    Valladolid_Pisuerga = 151
    Valsain = 152
    Vegacerneja = 153
    Vegalatrave = 154
    VelillaDeLaValduerna = 155
    Ventanilla = 156
    VillaescusaDeLasTorres = 157
    VillalcazarDeSirga = 158
    Villallano = 159
    Villalobar = 160
    Villamanin = 161
    VillanuevaDeLosInfantes = 162
    Villardiga = 163
    VillaverdeDeArcayos = 164
    VillavezaDeValverde = 165
    Villoldo = 166
    Villomar = 167
    VillovelaDePiron = 168
    Vinuesa = 169
    Zamarra = 170
    Zamora = 171