from saih_duero_scraping.gauging_enum import GaugingStation
from saih_duero_scraping.gauging import Gauging

GaugingCollection = {
        GaugingStation.AbiaDeLasTorres : Gauging(name='Abia de Las Torres',gauging_code= 2026),
        GaugingStation.Aguilafuente : Gauging(name='Aguilafuente',gauging_code= 2517),
        GaugingStation.AlarDelRey : Gauging(name='Alar del Rey',gauging_code= 2024),
        GaugingStation.Alconada : Gauging(name='Alconada',gauging_code= 2712),
        GaugingStation.AlijaDeLaRibera : Gauging(name='Alija de la Ribera',gauging_code= 2119),
        GaugingStation.Almazan : Gauging(name='Almazan',gauging_code= 2163),
        GaugingStation.Ambasaguas : Gauging(name='Ambasaguas',gauging_code= 2147),
        GaugingStation.ArandaDeDuero : Gauging(name='Aranda de Duero',gauging_code= 2013),
        GaugingStation.Arbejal : Gauging(name='Arbejal',gauging_code= 2106),
        GaugingStation.Arevalo : Gauging(name='Arevalo',gauging_code= 2158),
        GaugingStation.Avila : Gauging(name='Avila',gauging_code= 2046),
        GaugingStation.BarbadilloDelPez : Gauging(name='Barbadillo del Pez',gauging_code= 2123),
        GaugingStation.Benamariel2 : Gauging(name='Benamariel 2',gauging_code= 2711),
        GaugingStation.Benegiles : Gauging(name='Benegiles',gauging_code= 2548),
        GaugingStation.Bernardos : Gauging(name='Bernardos',gauging_code= 2053),
        GaugingStation.Besande : Gauging(name='Besande',gauging_code= 2034),
        GaugingStation.BocaDeHuergano : Gauging(name='Boca de Huergano',gauging_code= 2550),
        GaugingStation.Boisan : Gauging(name='Boisan',gauging_code= 2519),
        GaugingStation.Breto : Gauging(name='Breto',gauging_code= 2530),
        GaugingStation.BrimeDeUrz : Gauging(name='Brime de Urz',gauging_code= 2719),
        GaugingStation.Burgos_Arlanzon : Gauging(name='Burgos - Arlanzon',gauging_code= 2139),
        GaugingStation.Burgos_Vena : Gauging(name='Burgos - Vena',gauging_code= 2549),
        GaugingStation.CabanesDeEsgueva : Gauging(name='Cabanes de Esgueva',gauging_code= 2049),
        GaugingStation.CabezonDePisuerga : Gauging(name='Cabezon de Pisuerga',gauging_code= 2043),
        GaugingStation.CaldasDeNocedo : Gauging(name='Caldas de Nocedo',gauging_code= 2068),
        GaugingStation.Camarzana_Regato : Gauging(name='Camarzana - Regato',gauging_code= 2716),
        GaugingStation.CamarzanaDeTera : Gauging(name='Camarzana de Tera',gauging_code= 2541),
        GaugingStation.Camposolillo : Gauging(name='Camposolillo',gauging_code= 2078),
        GaugingStation.CardanoDeArriba : Gauging(name='Cardano de Arriba',gauging_code= 2511),
        GaugingStation.Cascantes : Gauging(name='Cascantes',gauging_code= 2510),
        GaugingStation.CastreloDoVal : Gauging(name='Castrelo do Val',gauging_code= 2160),
        GaugingStation.CastroDeLaLomba : Gauging(name='Castro de La Lomba',gauging_code= 2138),
        GaugingStation.Castropepe : Gauging(name='Castropepe',gauging_code= 2074),
        GaugingStation.CebronesDelRio : Gauging(name='Cebrones del Rio',gauging_code= 2060),
        GaugingStation.CeladaDelCamino : Gauging(name='Celada del Camino',gauging_code= 2116),
        GaugingStation.CeladillaDelRio : Gauging(name='Celadilla del Rio',gauging_code= 2023),
        GaugingStation.Cistierna : Gauging(name='Cistierna',gauging_code= 2103),
        GaugingStation.CiudadRodrigo : Gauging(name='Ciudad Rodrigo',gauging_code= 2137),
        GaugingStation.Coca_Eresma : Gauging(name='Coca - Eresma',gauging_code= 2527),
        GaugingStation.Coca_Voltoya : Gauging(name='Coca - Voltoya',gauging_code= 2114),
        GaugingStation.Cordovilla : Gauging(name='Cordovilla',gauging_code= 2029),
        GaugingStation.Covarrubias : Gauging(name='Covarrubias',gauging_code= 2030),
        GaugingStation.Cremenes : Gauging(name='Cremenes',gauging_code= 2151),
        GaugingStation.ElBarcoDeAvila : Gauging(name='El Barco de Avila',gauging_code= 2085),
        GaugingStation.EmisarioDeLaNava : Gauging(name='Emisario de La Nava',gauging_code= 2135),
        GaugingStation.EncinasDeAbajo : Gauging(name='Encinas de Abajo',gauging_code= 2545),
        GaugingStation.Garray_Soria : Gauging(name='Garray - Soria',gauging_code= 2002),
        GaugingStation.Genestacio : Gauging(name='Genestacio',gauging_code= 2718),
        GaugingStation.Getino : Gauging(name='Getino',gauging_code= 2542),
        GaugingStation.Gormaz : Gauging(name='Gormaz',gauging_code= 2004),
        GaugingStation.Guardo : Gauging(name='Guardo',gauging_code= 2134),
        GaugingStation.GuijasAlbas : Gauging(name='Guijas Albas',gauging_code= 2052),
        GaugingStation.HerreraDeDuero : Gauging(name='Herrera de Duero',gauging_code= 2015),
        GaugingStation.HerreraDePisuerga : Gauging(name='Herrera de Pisuerga',gauging_code= 2133),
        GaugingStation.HoyosDelEspino : Gauging(name='Hoyos del Espino',gauging_code= 2006),
        GaugingStation.LaFuentona : Gauging(name='La Fuentona',gauging_code= 2153),
        GaugingStation.LaMagdalena : Gauging(name='La Magdalena',gauging_code= 2075),
        GaugingStation.Languilla : Gauging(name='Languilla',gauging_code= 2538),
        GaugingStation.LasOmanas : Gauging(name='Las Omanas',gauging_code= 2076),
        GaugingStation.LasSalas : Gauging(name='Las Salas',gauging_code= 2102),
        GaugingStation.Ledesma : Gauging(name='Ledesma',gauging_code= 2546),
        GaugingStation.Leon : Gauging(name='Leon',gauging_code= 2115),
        GaugingStation.Lerma : Gauging(name='Lerma',gauging_code= 2507),
        GaugingStation.Liegos : Gauging(name='Liegos',gauging_code= 2529),
        GaugingStation.LinaresDelArroyo : Gauging(name='Linares del Arroyo',gauging_code= 2010),
        GaugingStation.LosAngelesDeSanRafael : Gauging(name='Los Angeles de San Rafael',gauging_code= 2055),
        GaugingStation.Manganeses : Gauging(name='Manganeses',gauging_code= 2145),
        GaugingStation.MedianaDeVoltoya : Gauging(name='Mediana de Voltoya',gauging_code= 2047),
        GaugingStation.MedinaDeRioseco : Gauging(name='Medina de Rioseco',gauging_code= 2124),
        GaugingStation.MedinaDelCampo : Gauging(name='Medina del Campo',gauging_code= 2551),
        GaugingStation.Megeces : Gauging(name='Megeces',gauging_code= 2518),
        GaugingStation.MolinosDeDuero : Gauging(name='Molinos de Duero',gauging_code= 2101),
        GaugingStation.Monderio : Gauging(name='Monderio',gauging_code= 2533),
        GaugingStation.MoralesDelRey : Gauging(name='Morales del Rey',gauging_code= 2082),
        GaugingStation.MorlaDeLaValderia : Gauging(name='Morla de La Valderia',gauging_code= 2089),
        GaugingStation.MozarDeValverde : Gauging(name='Mozar de Valverde',gauging_code= 2099),
        GaugingStation.Navapalos : Gauging(name='Navapalos',gauging_code= 2017),
        GaugingStation.Osma : Gauging(name='Osma',gauging_code= 2005),
        GaugingStation.OteroDeGuardo : Gauging(name='Otero de Guardo',gauging_code= 2035),
        GaugingStation.PajaresDePedraza : Gauging(name='Pajares de Pedraza',gauging_code= 2016),
        GaugingStation.PalaciosDeLaSierra : Gauging(name='Palacios de la Sierra',gauging_code= 2165),
        GaugingStation.Palencia : Gauging(name='Palencia',gauging_code= 2042),
        GaugingStation.Pardave : Gauging(name='Pardave',gauging_code= 2150),
        GaugingStation.PedrosaDelPrincipe : Gauging(name='Pedrosa del Principe',gauging_code= 2018),
        GaugingStation.PeralDeArlanza : Gauging(name='Peral de Arlanza',gauging_code= 2031),
        GaugingStation.PinedaDeLaSierra : Gauging(name='Pineda de la Sierra',gauging_code= 2508),
        GaugingStation.PinillaDeLosMoros : Gauging(name='Pinilla de Los Moros',gauging_code= 2141),
        GaugingStation.PueblaDeSanabria : Gauging(name='Puebla de Sanabria',gauging_code= 2080),
        GaugingStation.PuenteCongosto : Gauging(name='Puente Congosto',gauging_code= 2081),
        GaugingStation.PuenteResbala : Gauging(name='Puente Resbala',gauging_code= 2094),
        GaugingStation.QuintanaDelCastillo : Gauging(name='Quintana del Castillo',gauging_code= 2547),
        GaugingStation.QuintanaDelPuente : Gauging(name='Quintana del Puente',gauging_code= 2036),
        GaugingStation.Quintanaduenas : Gauging(name='Quintanaduenas',gauging_code= 2159),
        GaugingStation.QuintanillaDeOnesimo : Gauging(name='Quintanilla de Onesimo',gauging_code= 2132),
        GaugingStation.Rabal : Gauging(name='Rabal',gauging_code= 2818),
        GaugingStation.Remolina : Gauging(name='Remolina',gauging_code= 2157),
        GaugingStation.Resoba : Gauging(name='Resoba',gauging_code= 2537),
        GaugingStation.Riaza : Gauging(name='Riaza',gauging_code= 2009),
        GaugingStation.Robleda : Gauging(name='Robleda',gauging_code= 2502),
        GaugingStation.Ruesga : Gauging(name='Ruesga',gauging_code= 2022),
        GaugingStation.SaelicesElChico : Gauging(name='Saelices El Chico',gauging_code= 2505),
        GaugingStation.Sahagun : Gauging(name='Sahagun',gauging_code= 2073),
        GaugingStation.Salamanca : Gauging(name='Salamanca',gauging_code= 2087),
        GaugingStation.SalasDeLosInfantes : Gauging(name='Salas de los Infantes',gauging_code= 2028),
        GaugingStation.SalidaDelEmbalseDeAguilarDeCampoo : Gauging(name='Salida del Embalse de Aguilar de Campoo',gauging_code= 2020),
        GaugingStation.SalidaDelEmbalseDeArlanzon : Gauging(name='Salida del Embalse de Arlanzon',gauging_code= 2109),
        GaugingStation.SalidaDelEmbalseDeBarriosDeLuna : Gauging(name='Salida del Embalse de Barrios de Luna',gauging_code= 2122),
        GaugingStation.SalidaDelEmbalseDeCamporredondo : Gauging(name='Salida del Embalse de Camporredondo',gauging_code= 2108),
        GaugingStation.SalidaDelEmbalseDeCasares : Gauging(name='Salida del Embalse de Casares',gauging_code= 2514),
        GaugingStation.SalidaDelEmbalseDeCastroDeLasCogotas : Gauging(name='Salida del Embalse de Castro de las Cogotas',gauging_code= 2500),
        GaugingStation.SalidaDelEmbalseDeCastrovido : Gauging(name='Salida del Embalse de Castrovido',gauging_code= 2166),
        GaugingStation.SalidaDelEmbalseDeCervera : Gauging(name='Salida del Embalse de Cervera',gauging_code= 2107),
        GaugingStation.SalidaDelEmbalseDeCompuerto : Gauging(name='Salida del Embalse de Compuerto',gauging_code= 2037),
        GaugingStation.SalidaDelEmbalseDeElPontonAlto : Gauging(name='Salida del Embalse de El Ponton Alto',gauging_code= 2526),
        GaugingStation.SalidaDelEmbalseDeIruena : Gauging(name='Salida del Embalse de Iruena',gauging_code= 2503),
        GaugingStation.SalidaDelEmbalseDeLaCuerdaDelPozo : Gauging(name='Salida del Embalse de La Cuerda del Pozo',gauging_code= 2001),
        GaugingStation.SalidaDelEmbalseDeLasVencias : Gauging(name='Salida del Embalse de Las Vencias',gauging_code= 2161),
        GaugingStation.SalidaDelEmbalseDeLinares : Gauging(name='Salida del Embalse de Linares',gauging_code= 2552),
        GaugingStation.SalidaDelEmbalseDeSantaTeresa : Gauging(name='Salida del Embalse de Santa Teresa',gauging_code= 2140),
        GaugingStation.SalidaDelEmbalseDeUzquiza : Gauging(name='Salida del Embalse de Uzquiza',gauging_code= 2032),
        GaugingStation.SalidaDelEmbalseDeVillameca : Gauging(name='Salida del Embalse de Villameca',gauging_code= 2077),
        GaugingStation.SalidaDelEmbalseDelAgueda : Gauging(name='Salida del Embalse del Agueda',gauging_code= 2092),
        GaugingStation.SalidaDelEmbalseDelPorma : Gauging(name='Salida del Embalse del Porma',gauging_code= 2011),
        GaugingStation.SalinasDePisuerga : Gauging(name='Salinas de Pisuerga',gauging_code= 2019),
        GaugingStation.SanFelixDeLaVega : Gauging(name='San Felix de La Vega',gauging_code= 2156),
        GaugingStation.SanMiguelDelPino : Gauging(name='San Miguel del Pino',gauging_code= 2054),
        GaugingStation.SanSalvadorDeCantamuda : Gauging(name='San Salvador de Cantamuda',gauging_code= 2536),
        GaugingStation.SantaCristinaDeLaPolvorosa : Gauging(name='Santa Cristina de la Polvorosa',gauging_code= 2079),
        GaugingStation.SantaEulaliaDeRionegro : Gauging(name='Santa Eulalia de Rionegro',gauging_code= 2113),
        GaugingStation.SantaMarinaDelRey : Gauging(name='Santa Marina del Rey',gauging_code= 2061),
        GaugingStation.SantervasDeCampos : Gauging(name='Santervas de Campos',gauging_code= 2105),
        GaugingStation.SantiagoDeLaValduerna : Gauging(name='Santiago de la Valduerna',gauging_code= 2713),
        GaugingStation.Saucelle_Duero : Gauging(name='Saucelle - Duero',gauging_code= 2524),
        GaugingStation.Saucelle_Huebra : Gauging(name='Saucelle - Huebra',gauging_code= 2531),
        GaugingStation.Secos : Gauging(name='Secos',gauging_code= 2112),
        GaugingStation.Segovia : Gauging(name='Segovia',gauging_code= 2050),
        GaugingStation.SenaDeLuna : Gauging(name='Sena de Luna',gauging_code= 2532),
        GaugingStation.Sepulveda : Gauging(name='Sepulveda',gauging_code= 2012),
        GaugingStation.TardajosDeDuero : Gauging(name='Tardajos de Duero',gauging_code= 2162),
        GaugingStation.Tardesillas : Gauging(name='Tardesillas',gauging_code= 2164),
        GaugingStation.TolibiaDeAbajo : Gauging(name='Tolibia de Abajo',gauging_code= 2063),
        GaugingStation.Toro_Duero : Gauging(name='Toro - Duero',gauging_code= 2062),
        GaugingStation.Toro_Guarena : Gauging(name='Toro - Guarena',gauging_code= 2129),
        GaugingStation.TorreDeEsgueva : Gauging(name='Torre de Esgueva',gauging_code= 2528),
        GaugingStation.Triollo : Gauging(name='Triollo',gauging_code= 2512),
        GaugingStation.Ucero : Gauging(name='Ucero',gauging_code= 2154),
        GaugingStation.Vadocondes : Gauging(name='Vadocondes',gauging_code= 2522),
        GaugingStation.Valderas : Gauging(name='Valderas',gauging_code= 2516),
        GaugingStation.Valdestillas : Gauging(name='Valdestillas',gauging_code= 2056),
        GaugingStation.Valladolid_Esgueva : Gauging(name='Valladolid - Esgueva',gauging_code= 2044),
        GaugingStation.Valladolid_Pisuerga : Gauging(name='Valladolid - Pisuerga',gauging_code= 2097),
        GaugingStation.Valsain : Gauging(name='Valsain',gauging_code= 2525),
        GaugingStation.Vegacerneja : Gauging(name='Vegacerneja',gauging_code= 2535),
        GaugingStation.Vegalatrave : Gauging(name='Vegalatrave',gauging_code= 2155),
        GaugingStation.VelillaDeLaValduerna : Gauging(name='Velilla de la Valduerna',gauging_code= 2520),
        GaugingStation.Ventanilla : Gauging(name='Ventanilla',gauging_code= 2539),
        GaugingStation.VillaescusaDeLasTorres : Gauging(name='Villaescusa de Las Torres',gauging_code= 2131),
        GaugingStation.VillalcazarDeSirga : Gauging(name='Villalcazar de Sirga',gauging_code= 2041),
        GaugingStation.Villallano : Gauging(name='Villallano',gauging_code= 2136),
        GaugingStation.Villalobar : Gauging(name='Villalobar',gauging_code= 2710),
        GaugingStation.Villamanin : Gauging(name='Villamanin',gauging_code= 2098),
        GaugingStation.VillanuevaDeLosInfantes : Gauging(name='Villanueva de los Infantes',gauging_code= 2025),
        GaugingStation.Villardiga : Gauging(name='Villardiga',gauging_code= 2126),
        GaugingStation.VillaverdeDeArcayos : Gauging(name='Villaverde de Arcayos',gauging_code= 2104),
        GaugingStation.VillavezaDeValverde : Gauging(name='Villaveza de Valverde',gauging_code= 2717),
        GaugingStation.Villoldo : Gauging(name='Villoldo',gauging_code= 2040),
        GaugingStation.Villomar : Gauging(name='Villomar',gauging_code= 2111),
        GaugingStation.VillovelaDePiron : Gauging(name='Villovela de Piron',gauging_code= 2057),
        GaugingStation.Vinuesa : Gauging(name='Vinuesa',gauging_code= 2000),
        GaugingStation.Zamarra : Gauging(name='Zamarra',gauging_code= 2501),
        GaugingStation.Zamora : Gauging(name='Zamora',gauging_code= 2121)
}